ODS GRAPHICS OFF;
ODS HTML CLOSE;
ODS LISTING;

DATA wght_long;
	INFILE 'C:\GRE2016\Data\wght_data.dat';
	INPUT id occ occ_begin year time_in_study grade age gyn_age wght;
RUN;

*Restucturing the data by age;
DATA wght_long1;
	SET wght_long;
	age_r = ROUND(age);
	IF wght ne .;
RUN;

PROC MEANS;
	VAR wght age_r;
RUN;

PROC FREQ DATA = wght_long1;
	TABLES age_r;
RUN;

PROC SORT DATA = wght_long1;
	BY id age_r;
RUN;

DATA wght_wide;
	ARRAY  wght_[5:19] wght5-wght19;
	RETAIN wght5-wght19;

	SET wght_long1;
	BY id;
	IF FIRST.id THEN DO I = 5 TO 19;
		wght_[I] 	= .;
	END;
	wght_[age_r] = wght;
	IF LAST.id THEN OUTPUT;
	KEEP id wght5-wght19;
RUN;

* Writing out dataset;
DATA _NULL_ ;
	SET wght_wide ;
	FILE 'C:\GRE2016\Data\wght_wide.dat';
	PUT id wght5-wght19;
RUN;


*Restucturing wght_wide back into long format;
DATA wght_long_new;
  SET wght_wide;
  ARRAY wght_[5:19] wght5-wght19;

  DO age_r = 5 to 19;
    wght = wght_[age_r];
    OUTPUT;
  END ;

  KEEP id age_r wght; 
RUN;
DATA wght_wide_new1;
	SET wght_wide_new;
	IF wght ne .; 
RUN;



** Plotting **;

GOPTIONS RESET = all;
GOPTIONS
	HTEXT = 1.5
	CTEXT = black
	FTEXT = 'Albany AMT';

PROC GPLOT DATA = wght_long;
	TITLE ' ';
	SYMBOL1
		INTERPOL = join
		REPEAT = 5000
		VALUE = dot
		HEIGHT = .5
		WIDTH = 1
		COLOR = black;
	AXIS1
		LABEL = (A = 90 F = 'Albany AMT' H = 2 'Weight')
		ORDER = (25 to 225 BY 25)
		MINOR = none
		OFFSET= (2 pct, 2 pct);	

	AXIS2
		LABEL = (F = 'Albany AMT' H = 2 'Chronological Age')
		ORDER = (5 to 17 BY 2)
		MINOR = none
		OFFSET= (2 pct, 2 pct);

	PLOT wght*age=id /HAXIS = AXIS2 VAXIS = AXIS1 NOLEGEND;
RUN;

PROC GPLOT DATA = wght_long (where = (id > 1300 AND id < 1600));
	TITLE ' ';
	SYMBOL1
		INTERPOL = join
		REPEAT = 5000
		VALUE = dot
		HEIGHT = .5
		WIDTH = 1
		COLOR = black;
	AXIS1
		LABEL = (A = 90 F = 'Albany AMT' H = 2 'Weight')
		ORDER = (25 to 225 BY 25)
		MINOR = none
		OFFSET= (2 pct, 2 pct);	

	AXIS2
		LABEL = (F = 'Albany AMT' H = 2 'Chronological Age')
		ORDER = (5 to 17 BY 2)
		MINOR = none
		OFFSET= (2 pct, 2 pct);

	PLOT wght*age=id /HAXIS = AXIS2 VAXIS = AXIS1 NOLEGEND;
RUN;


ODS LISTING STYLE = journal image_dpi=300;
ODS GRAPHICS ON / RESET=ALL IMAGEFMT=png WIDTH=4in IMAGENAME='Long_Plot';
PROC SGPLOT DATA = wght_long (where = (id > 1300 AND id < 1600));
	SERIES X = age Y = wght / GROUP=id
           LINEATTRS   = (COLOR=black PATTERN=solid THICKNESS=1)
		   MARKERATTRS = (COLOR=black SIZE=3 SYMBOL=circlefilled)
		   MARKERS;
	YAXIS LABEL = "Weight"   VALUES = (25 to 225 BY 25);* OFFSETMIN=0.05 OFFSETMAX=0.07;
	XAXIS LABEL = "Chronological Age" VALUES = (5 to 17 BY 2);* OFFSETMIN=0.05 OFFSETMAX=0.07;
RUN;
ODS GRAPHICS OFF;


* Descriptive Statistics - using wide dataset;
PROC MEANS DATA = wght_wide N MEAN STD MIN MAX SKEW KURT MAXDEC=2;
	VAR wght5-wght19;
RUN;

PROC CORR DATA = wght_wide COV;
	VAR wght5-wght19;
RUN;

ODS LISTING STYLE = journal image_dpi=300;
ODS GRAPHICS ON / RESET=ALL IMAGEFMT=png WIDTH=6in IMAGENAME='Matrix';
PROC SGSCATTER DATA = wght_wide;
	MATRIX wght5-wght10 / DIAGONAL=(HISTOGRAM);
RUN;
ODS GRAPHICS OFF;

* Additional Figures;
PROC GPLOT DATA = wght_long (where = (id > 1300 AND id < 1600));
	TITLE ' ';
	SYMBOL1
		I = join
		R = 5000
		V = dot
		H = .5
		W = 1
		C = black;
	AXIS1
		LABEL = (A = 90 F = 'Albany AMT' H = 2 'Weight')
		ORDER = (25 to 225 BY 25)
		MINOR = none
		OFFSET= (2 pct, 2 pct);	
	AXIS2
		LABEL = (F = 'Albany AMT' H = 2 'Measurement Occasion')
		ORDER = (1 to 5 BY 1)
		MINOR = none
		OFFSET= (2 pct, 2 pct);
	PLOT wght*occ=id /VAXIS = AXIS1 HAXIS = AXIS2 NOLEGEND;
RUN;

PROC GPLOT DATA = wght_long (where = (id > 1300 AND id < 1600));
	TITLE ' ';
	SYMBOL1
		I = join
		R = 5000
		V = dot
		H = .5
		W = 1
		C = black;
	AXIS2
		LABEL = (F = 'Albany AMT' H = 2 'Measurement Occasion')
		ORDER = (1 to 5 BY 1)
		MINOR = none
		OFFSET= (2 pct, 2 pct);
	PLOT wght*occ_begin=id /VAXIS = AXIS1 HAXIS = AXIS2 NOLEGEND;
RUN;

PROC GPLOT DATA = wght_long (where = (id > 1300 AND id < 1600));
	TITLE ' ';
	SYMBOL1
		I = join
		R = 5000
		V = dot
		H = .5
		W = 1
		C = black;
	AXIS2
		LABEL = (F = 'Albany AMT' H = 2 'Year of Study')
		ORDER = (1986 to 2002 BY 2)
		MINOR = none
		OFFSET= (2 pct, 2 pct);
	PLOT wght*year=id /VAXIS = AXIS1 HAXIS = AXIS2 NOLEGEND;
RUN;

PROC GPLOT DATA = wght_long (where = (id > 1300 AND id < 1600));
	TITLE ' ';
	SYMBOL1
		I = join
		R = 5000
		V = dot
		H = .5
		W = 1
		C = black;
	AXIS2
		LABEL = (F = 'Albany AMT' H = 2 'Time in Study')
		ORDER = (0 to 10 BY 2)
		MINOR = none
		OFFSET= (2 pct, 2 pct);

	PLOT wght*time_in_study=id /HAXIS = AXIS2 VAXIS = AXIS1 NOLEGEND;
RUN;

PROC GPLOT DATA = wght_long (where = (id > 1300 AND id < 1600));
	TITLE ' ';
	SYMBOL1
		I = join
		R = 5000
		V = dot
		H = .5
		W = 1
		C = black;
	AXIS2
		LABEL = (F = 'Albany AMT' H = 2 'Grade')
		ORDER = (0 to 10 BY 2)
		MINOR = none
		OFFSET= (2 pct, 2 pct);
	PLOT wght*grade=id / VAXIS = AXIS1 HAXIS = AXIS2 NOLEGEND;
RUN;

PROC GPLOT DATA = wght_long (where = (id > 1300 AND id < 1600));
	TITLE ' ';
	SYMBOL1
		INTERPOL = join
		REPEAT = 5000
		VALUE = dot
		HEIGHT = .5
		WIDTH = 1
		COLOR = black;
	AXIS2
		LABEL = (F = 'Albany AMT' H = 2 'Chronological Age')
		ORDER = (5 to 17 BY 2)
		MINOR = none
		OFFSET= (2 pct, 2 pct);

	PLOT wght*age=id /HAXIS = AXIS2 VAXIS = AXIS1 NOLEGEND;
RUN;


PROC GPLOT DATA = wght_long (where = (id > 1300 AND id < 1600));
	TITLE ' ';
	SYMBOL1
		I = join
		R = 5000
		V = dot
		H = .5
		W = 1
		C = black; 
	AXIS2
		LABEL = (F = 'Albany AMT' H = 2 'Gynecological Age' )
		ORDER = (-8 to 5 BY 1)
		MINOR = none
		OFFSET= (2 pct, 2 pct);

	PLOT wght*gyn_age=id /VAXIS = AXIS1 HAXIS = AXIS2 NOLEGEND;
RUN;
